## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 3;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global common_description %{expand:
Highway is a C++ library for SIMD (Single Instruction, Multiple Data), i.e.
applying the same operation to 'lanes'.}

%global toolchain clang

%if 0%{?rhel}
%bcond gtest 0
%bcond contrib 0
%else
%bcond gtest 1
%bcond contrib 1
%endif

Name:           highway
Version:        1.2.0
Release:        %autorelease
Summary:        Efficient and performance-portable SIMD

License:        Apache-2.0
URL:            https://github.com/google/highway
Source:         %url/archive/%{version}/%{name}-%{version}.tar.gz
# [PATCH] Made fixes to generic_ops-inl.h BitShuffle impl on big-endian
Patch:          %url/commit/3ce50ffa85577140bdf088d8ee7830b76ac2501c.patch
# [PATCH] Disable RVV runtime dispatch. Fixes #2227
#
# Public Clang <= 18 still appears to require compiler flags for RVV.
# GCC 13 also has an #error and 14 is missing mulh/mulhu.
#
# Also split HWY_HAVE_RUNTIME_DISPATCH into multiple macros to enable
# overriding parts of the logic.
Patch:          %url/commit/c95cc0237d2f7a0f5ca5dc3fb4b5961b2b1dcdfc.patch

BuildRequires:  cmake
BuildRequires:  clang
%if %{with gtest}
BuildRequires:  gtest-devel
%endif
BuildRequires:  libatomic

%description
%common_description

%package        devel
Summary:        Development files for Highway
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
%{common_description}

Development files for Highway.

%package        doc
Summary:        Documentation for Highway
BuildArch:      noarch

%description doc
%{common_description}

Documentation for Highway.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%cmake %{!?with_gtest:-DHWY_ENABLE_TESTS:BOOL=OFF} \
       %{?with_gtest:-DHWY_SYSTEM_GTEST:BOOL=ON} \
       %{!?with_contrib:-DHWY_ENABLE_CONTRIB:BOOL=OFF} \
       -DHWY_CMAKE_RVV:BOOL=OFF
%cmake_build

%install
%cmake_install

%if %{without gtest}
rm -vf %{buildroot}%{_libdir}/libhwy_test.so.*
rm -vrf %{buildroot}%{_includedir}/hwy/tests
rm -vf %{buildroot}%{_libdir}/libhwy_test.so
rm -vf %{buildroot}%{_libdir}/pkgconfig/libhwy-test.pc
%endif

%if %{without contrib}
rm -vf %{buildroot}%{_libdir}/libhwy_contrib.so.*
rm -vrf %{buildroot}%{_includedir}/hwy/contrib
rm -vf %{buildroot}%{_libdir}/libhwy_contrib.so
rm -vf %{buildroot}%{_libdir}/pkgconfig/libhwy-contrib.pc
%endif

%check
%ctest

%files
%license LICENSE
%{_libdir}/libhwy.so.1
%{_libdir}/libhwy.so.%{version}
%if %{with contrib}
%{_libdir}/libhwy_contrib.so.1
%{_libdir}/libhwy_contrib.so.%{version}
%endif
%if %{with gtest}
%{_libdir}/libhwy_test.so.1
%{_libdir}/libhwy_test.so.%{version}
%endif

%files devel
%license LICENSE
%{_includedir}/hwy/
%{_libdir}/cmake/hwy/
%{_libdir}/libhwy.so
%if %{with contrib}
%{_libdir}/libhwy_contrib.so
%{_libdir}/pkgconfig/libhwy-contrib.pc
%endif
%if %{with gtest}
%{_libdir}/libhwy_test.so
%{_libdir}/pkgconfig/libhwy-test.pc
%endif
%{_libdir}/pkgconfig/libhwy.pc

%files doc
%license LICENSE
%doc g3doc hwy/examples

%changelog
## START: Generated by rpmautospec
* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Fri Jun 07 2024 Robert-André Mauchin <zebob.m@gmail.com> - 1.2.0-2
- Fix s390x tests and RISCV build
- Introduces a patch that fix tests on BigEndian
- Introduces a patch that disable RVV runtime dispatch for RISCV builds

* Sat Jun 01 2024 Robert-André Mauchin <zebob.m@gmail.com> - 1.2.0-1
- Update to 1.2.0

* Sat Feb 24 2024 Fabio Valentini <decathorpe@gmail.com> - 1.1.0-1
- Update to version 1.1.0; Fixes RHBZ#2264702

* Wed Jan 24 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sat Jan 20 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Sep 01 2023 Fabio Valentini <decathorpe@gmail.com> - 1.0.7-1
- Update to version 1.0.7; Fixes RHBZ#2231570

* Sat Jul 29 2023 Fabio Valentini <decathorpe@gmail.com> - 1.0.5-1
- Update to version 1.0.5; Fixes RHBZ#2224097

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sun Jun 25 2023 Jiri Kucera <jkucera@redhat.com> - 1.0.4-2
- Drop gtest on RHEL

* Sat Mar 18 2023 Robert-André Mauchin <zebob.m@gmail.com> - 1.0.4-1
- Update to 1.0.4

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Dec 27 2022 Robert-André Mauchin <zebob.m@gmail.com> - 1.0.2-1
- Update to 1.0.2

* Sat Nov 19 2022 Robert-André Mauchin <zebob.m@gmail.com> - 1.0.1-2
- Disable SortTestGroup/SortTest.TestAllSort/Scalar test

* Sun Sep 18 2022 Robert-André Mauchin <zebob.m@gmail.com> - 1.0.1-1
- Update to 1.0.1

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.17.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sun Jun 19 2022 Robert-André Mauchin <zebob.m@gmail.com> - 0.17.0-1
- Update to 0.17.0 Close: rhbz#2056027

* Fri Jan 21 2022 Robert-André Mauchin <zebob.m@gmail.com> - 0.15.0-4
- Temporary fix for bug 398

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Dec 17 2021 Robert-André Mauchin <zebob.m@gmail.com> - 0.15.0-2
- Remove unused patch

* Sun Nov 21 2021 Robert-André Mauchin <zebob.m@gmail.com> - 0.15.0-1
- Update to 0.15.0 Close: rhbz#1997317

* Wed Aug 18 2021 Robert-André Mauchin <zebob.m@gmail.com> - 0.14.1-2
- Add patch to fix missing cast on ppc64le

* Wed Aug 18 2021 Robert-André Mauchin <zebob.m@gmail.com> - 0.14.1-1
- Update to 0.14.1 Close: rhbz#1988346

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.12.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sun Jun 13 13:04:25 CEST 2021 Robert-André Mauchin <zebob.m@gmail.com> - 0.12.2-1
- Update to 0.12.2

* Sun May 23 19:03:29 CEST 2021 Robert-André Mauchin <zebob.m@gmail.com> - 0.12.1-1
- Update to 0.12.0
- Close: rhbz#1963675

* Mon May 17 18:03:58 CEST 2021 Robert-André Mauchin <zebob.m@gmail.com> - 0.12.0-1.20210518git376a400
- Initial RPM

## END: Generated by rpmautospec
